@@ -9,10 +9,10 @@ from typing import List
 
 import youtube_dl
 
-from pyscrapers.configs import ConfigYoutubeDl, ConfigUrl
+from pyscrapers.configs import ConfigYoutubeDl, ConfigUrl, ConfigDownload
 
 
-class MyLogger(object):
+class MyLogger:
     def debug(self, msg):
         pass
 
@@ -33,11 +33,14 @@ def youtube_dl_download_url(url: str) -> None:
 
 
 def youtube_dl_download_urls(urls: List[str]) -> None:
+    if not ConfigDownload.download:
+        return
     ydl_opts = {
         'format': 'bestaudio/best',
         # 'logger': MyLogger(),
-        'nooverwrites': True,
-        'ignoreerrors': True,
+        'no-overwrites': True,
+        'ignore-errors': True,
+        'hls-prefer-native': True,
     }
     if ConfigYoutubeDl.use_archive:
         ydl_opts['download_archive'] = ConfigYoutubeDl.archive_file
